#!/usr/bin/env python
# -*- coding: utf-8 -*-

import psutil

def mem_status():
    data = {}

    vmem = dict(psutil.virtual_memory()._asdict())
    data['mem.free_kb'] = int(vmem['available']) / 1024
    data['mem.total_kb'] = int(vmem['total']) / 1024
    data['mem.used_kb'] = data['mem.total_kb'] - data['mem.free_kb']
    data['mem.used_pct'] = int(vmem['percent'])

    swap = dict(psutil.swap_memory()._asdict())
    data['swap.free_kb'] = int(vmem['free']) / 1024
    data['swap.total_kb'] = int(vmem['total']) / 1024
    data['swap.used_kb'] = int(vmem['used']) / 1024
    data['swap.used_pct'] = int(vmem['percent'])

    return data

if __name__ == "__main__":
    print mem_status()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from subprocess import Popen, PIPE

def virtual_info():
    output = Popen(['lspci'], stdout=PIPE).communicate()[0]

    data = { 'system.is_virtual': False }
    model = output.lower()
    if 'system.vmware' in model:
       data['system.virtual'] = 'VMware'
       data['system.is_virtual'] = True
    elif 'virtualbox' in model:
       data['system.virtual'] = 'VirtualBox'
       data['system.is_virtual'] = True
    elif 'qemu' in model:
       data['system.virtual'] = 'kvm'
       data['system.is_virtual'] = True
    elif 'virtio' in model:
       data['system.virtual'] = 'kvm'
       data['systen.is_virtual'] = True
    return data

if __name__ == "__main__":
    print virtual_info()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os

def load_avg_status():
    data = {}

    loadavg = os.getloadavg()
    data['system.load_avg.1min_pct'] = loadavg[0]
    data['system.load_avg.5min_pct'] = loadavg[1]
    data['system.load_avg.15min_pct'] = loadavg[2]
    return data

if __name__ == "__main__":
    print load_avg_status()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import socket
import netifaces
import netaddr

exclude = ['lo', 'usb0', 'docker0']

def network_info():
    data = {}
    for ifn in netifaces.interfaces():
        link = netifaces.ifaddresses(ifn)[netifaces.AF_LINK][0]
        inet = None
        if ifn in exclude:
            continue
        try:
            inet = netifaces.ifaddresses(ifn)[netifaces.AF_INET][0]
        except:
            pass

        try:
            data['interface.' + ifn + '.ipv4'] = inet['addr']
        except:
            pass
        try:
            data['interface.' + ifn + '.broadcast'] = inet['broadcast']
        except:
            pass
        try:
            data['interface.' + ifn + '.netmask'] = inet['netmask']
        except:
            pass
        try:
            data['interface.' + ifn + '.hwaddr'] = link['addr']
        except:
            pass
        try:
            cidr = netaddr.IPNetwork('{0}/{1}'.format(inet['addr'], inet['netmask']))
            data['interface.' + ifn + '.network2'] = str(cidr.network)
        except:
            pass
    return data

if __name__ == "__main__":
    print network_info()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import psutil

def mem_info():
    data = {}

    vmem = dict(psutil.virtual_memory()._asdict())
    data['mem.total_kb'] = int(vmem['total']) / 1024

    return data

if __name__ == "__main__":
    print mem_info()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import psutil
from collections import namedtuple

allowed_fs = [ 'ext3', 'ext4', 'xfs', 'hfs' ]

def disk_status():
    data = {}

    for disk in psutil.disk_partitions():
        if disk.fstype in allowed_fs:
            usage = psutil.disk_usage(disk.mountpoint)
            if disk.mountpoint == '/':
                key = 'disk.root'
            else:
                key = 'disk.%s' % disk.mountpoint.lstrip('/').replace('/', '_').lower()
            data[key + '.mountpoint'] = disk.mountpoint
            data[key + '.free_kb'] = int(usage.free / 1024)
            data[key + '.total_kb'] = int(usage.total / 1024)
            data[key + '.used_kb'] = int(usage.used / 1024)
            data[key + '.used_pct'] = int(usage.percent)

    return data

if __name__ == "__main__":
    print disk_status()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
'''
Setup script for peekaboo
'''

from setuptools import setup, find_packages
import sys, os, glob

with open('requirements.txt') as f:
    requires = f.read().splitlines()

CLASSIFIERS = [
    'Development Status :: 5 - Production/Stable',
    'Environment :: Console',
    'Intended Audience :: System Administrators',
    'License :: OSI Approved :: Apache Software License',
    'Operating System :: POSIX :: Linux',
]

setup(
    name             = 'peekaboo',
    version          = '0.8.4',

    description      = 'Expose hardware info through HTTP',
    long_description = open("README.rst").read(),

    author           = 'Michael Persson',
    author_email     = 'michael.ake.persson@gmail.com',
    url              = 'https://github.com/mickep76/peekaboo.git',
    license          = 'Apache License, Version 2.0',

    packages         = find_packages(),
    classifiers      = CLASSIFIERS,
    scripts          = ['scripts/peekaboo'],
    data_files	     = [('/etc', ['etc/peekaboo.conf']),
                        ('/var/lib/peekaboo/plugins/info', glob.glob('plugins/info/*.py')),
                        ('/var/lib/peekaboo/plugins/status', glob.glob('plugins/status/*.py')),
			('/usr/share/peekaboo', ['LICENSE', 'README.rst']),
			('/usr/share/peekaboo/contrib', glob.glob('contrib/*'))],
    install_requires = requires,
)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import socket

def host_info():
    data = {}
    data['hostname'] = socket.gethostname()
    return data

if __name__ == "__main__":
    print host_info()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import psutil
from collections import namedtuple

def cpu_status():
    data = {}

    cpu = psutil.cpu_times()
    data['cpu.user_sec'] = cpu.user
    data['cpu.system_sec'] = cpu.system
    data['cpu.idle_sec'] = cpu.idle

    return data

if __name__ == "__main__":
    print cpu_status()

